import React from 'react';
import logo from '@assets/images/logo.png';
import userImage from '@assets/images/userImage.png';
import { Grid } from 'antd-mobile';
import QRCode from 'qrcode';

/**
 * @刘丹: 医生诊室叫号
 */
class DoctorScreen extends React.Component {
  constructor() {
    super();
    this.state = {

    };
  }
  componentDidMount() {
    this.getQrcSrc('https://www.kimi.com/');
  }
  componentDidUpdate(prev) {
    if (prev?.userData?.userQrCode != this.props.userData?.userQrCode) {
      this.getQrcSrc(this.props.userData?.userQrCode);
    }
  }
  // 链接转二维码链接
  getQrcSrc = (src) => {
    if (!src) {
      return;
    }
    QRCode.toDataURL(src).then((url) => {
      document.querySelector('#qrccodeimg').src = url;
    });
  };
  render() {
    const { userData = {}, patList = [] } = this.props;
    return (
      <div className='page-body big-scrren'>
        <div className='header'>
          <img
            src={this.props.hosLogo || logo}
            alt='Logo'
            className='logo'
            onError={(e) => {
              e.target.src = `${logo}`;
            }}
          />
          <span className='heaer-btn'>
            <span className='date'>接诊中</span>
            <br /> Opening
          </span>
        </div>
        <Grid  columns={3} gap={8}>
          <Grid.Item span={1}>
            <div className='section'>
              <div className='chinese-name big'>{userData.roomDesc || '诊区'}</div>
            </div>
          </Grid.Item>
          <Grid.Item span={2}>
            <div className='section'>
              <div className='chinese-name big'>{userData.locDesc || '科室'}</div>
            </div>
          </Grid.Item>
        </Grid>
        <div className='section mt'>
          <Grid columns={23} gap={8}>
            <Grid.Item span={4} style={{textAlign: 'center'}}>
              <img
                src={userData.userImage || userImage}
                className='user-header'
              />
            </Grid.Item>
            <Grid.Item span={8}>
              <div className='section section-inner'>
                <div className='chinese-name'>{userData.userDesc || '医生'}</div>
              </div>

            </Grid.Item>
            <Grid.Item span={11}>
              <div className='section section-inner'>
                <div className='chinese-name'>{userData.userTitleDesc  || '职称'}</div>
              </div>
            </Grid.Item>
          </Grid>
        </div>
        <div className='section mt'>
          <Grid  columns={4} gap={16}>
            <Grid.Item span={3}>
              <div className='doctor-profile'>
               {userData.userIntroduce  || '医生简介：暂无'}
              </div>
            </Grid.Item>
            <Grid.Item span={1}>
              <div className='center'>
                <img
                  className='qrccode-img'
                  id="qrccodeimg"
                />
              </div>
              <div className='qrccode-text'>扫码关注医师</div>
            </Grid.Item>
          </Grid>
        </div>
         <div className='table section'>
          <Grid  columns={12} gap={8}>
            <Grid.Item span={4}>
              <div className='table-header'>姓名</div>
            </Grid.Item>
            <Grid.Item span={4}>
              <div className='table-header'>就诊号</div>
            </Grid.Item>
             <Grid.Item span={4}>
              <div className='table-header'>状态</div>
            </Grid.Item>
          </Grid>
          {patList.map((item,index) => {
            return (<Grid  columns={12} gap={8} key={index}>
              <Grid.Item span={4}>
                <div className='table-content'>{item.patName || '***'}</div>
              </Grid.Item>
              <Grid.Item span={4}>
                <div className='table-content'>{item.patCallNo || '***'}</div>
              </Grid.Item>
              <Grid.Item span={4}>
                {item.status == 'waiting'
                  ? <div className='table-content waiting'>准备就诊</div>
                  : <div className='table-content sussess'>就诊中</div>
                }
              </Grid.Item>
            </Grid>);
          })}
        </div>
        <div className='footer'>请依据队列显示信息，依次排队就诊</div>
      </div>
    );
  }
}

export default DoctorScreen;
